@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from dataclasses import asdict, dataclass, is_dataclass
+from datetime import datetime
 from functools import cached_property
 from typing import Any, NamedTuple
 
@@ -9,12 +10,13 @@ from .consts import (
     ATTR_LABELS,
     EMBER_CUP,
     EMBER_TRAVEL_MUG,
+    EMBER_TRAVEL_MUG_SHORT,
     EXTRA_ATTRS,
     INITIAL_ATTRS,
-    TRAVEL_MUG_ATTRS,
     UPDATE_ATTRS,
     LiquidState,
     TemperatureUnit,
+    VolumeLevel,
 )
 from .formatting import format_led_colour, format_liquid_level, format_temp
 from .utils import bytes_to_little_int, decode_byte_string
@@ -38,20 +40,15 @@ class Colour(NamedTuple):
     red: int
     green: int
     blue: int
-    alpha: int | None = None
+    brightness: int = 255
 
     def as_hex(self) -> str:
         """Format colour array as hex string."""
-        return '#' + ''.join(f'{c:02x}' for c in self if c is not None)
+        return '#' + ''.join(f'{c:02x}' for c in self)[:6]
 
     def as_bytearray(self) -> bytearray:
         """Convert to byte array."""
-        return bytearray(c for c in self if c is not None)
-
-    @classmethod
-    def from_bytes(cls, data: bytes) -> Colour:
-        """Initialize from raw bytes."""
-        return cls(*data[:3])
+        return bytearray(c for c in self)
 
     def __str__(self) -> str:
         """For more useful cli output, format as hex."""
@@ -106,13 +103,21 @@ class MugFirmwareInfo:
         )
 
 
-@dataclass
+@dataclass(init=False)
 class Model:
     """Model name and attributes based on mode."""
 
     name: str
     include_extra: bool = False
 
+    def __init__(self, name: str, include_extra: bool = False) -> None:
+        """Override init to set long name for travel mug."""
+        if name == EMBER_TRAVEL_MUG_SHORT:
+            # Replace with full name for aesthetics
+            name = EMBER_TRAVEL_MUG
+        self.name = name
+        self.include_extra = include_extra
+
     @cached_property
     def is_cup(self) -> bool:
         """Check if the model is a Cup."""
@@ -121,7 +126,16 @@ class Model:
     @cached_property
     def is_travel_mug(self) -> bool:
         """Check if the model is a Travel mug."""
-        return self.name.startswith(EMBER_TRAVEL_MUG)
+        return self.name.startswith(EMBER_TRAVEL_MUG_SHORT)
+
+    @cached_property
+    def type(self) -> str:
+        """Model type as short string."""
+        if self.is_cup:
+            return "cup"
+        elif self.is_travel_mug:
+            return "travel_mug"
+        return "mug"
 
     @cached_property
     def attribute_labels(self) -> dict[str, str]:
@@ -136,6 +150,11 @@ class Model:
             return INITIAL_ATTRS - EXTRA_ATTRS
         return INITIAL_ATTRS
 
+    @cached_property
+    def all_attributes(self) -> set[str]:
+        """All attributes."""
+        return self.initial_attributes | self.update_attributes
+
     @cached_property
     def update_attributes(self) -> set[str]:
         """Attributes to update based on model and extra."""
@@ -143,9 +162,11 @@ class Model:
         if self.include_extra is False:
             attributes = attributes - EXTRA_ATTRS
         if self.is_cup:
+            # The Cup cannot be named
             attributes = attributes - {'name'}
         elif self.is_travel_mug:
-            attributes = attributes | TRAVEL_MUG_ATTRS
+            # Tge Travel Mug does not have an LED colour, but has a volume attribute
+            attributes = (attributes - {'led_colour'}) | {'volume_level'}
         return attributes
 
 
@@ -161,7 +182,7 @@ class MugMeta:
         """Initialize from raw bytes."""
         return cls(
             mug_id=decode_byte_string(data[:6]),
-            serial_number=data[7:].decode("utf-8"),
+            serial_number=data[7:].decode(),
         )
 
     def __str__(self) -> str:
@@ -182,16 +203,17 @@ class MugData:
     meta: MugMeta | None = None
     battery: BatteryInfo | None = None
     firmware: MugFirmwareInfo | None = None
-    led_colour: Colour = Colour(255, 255, 255)
+    led_colour: Colour = Colour(255, 255, 255, 255)
     liquid_state: LiquidState = LiquidState.UNKNOWN
     liquid_level: int = 0
     temperature_unit: TemperatureUnit = TemperatureUnit.CELSIUS
     current_temp: float = 0.0
     target_temp: float = 0.0
     dsk: str = ""
-    udsk: str = ""
-    date_time_zone: str = ""
-    battery_voltage: str = ""
+    udsk: str | None = ""
+    volume_level: VolumeLevel | None = None
+    date_time_zone: datetime | None = None
+    battery_voltage: int | None = None
 
     @property
     def meta_display(self) -> str:
@@ -210,6 +232,13 @@ class MugData:
         """Human-readable liquid state."""
         return self.liquid_state.label
 
+    @property
+    def volume_level_display(self) -> str | None:
+        """Human-readable volume level."""
+        if self.volume_level:
+            return self.volume_level.value.capitalize()
+        return None
+
     @property
     def liquid_level_display(self) -> str:
         """Human-readable liquid level."""
@@ -250,8 +279,9 @@ class MugData:
         data = {k: asdict(v) if is_dataclass(v) else v for k, v in asdict(self).items()}
         data.update(
             {
-                f'{attr}_display': getattr(self, f'{attr}_display')
-                for attr in ('led_colour', 'liquid_state', 'liquid_level', 'current_temp', 'target_temp')
+                f'{attr}_display': getattr(self, f'{attr}_display', None)
+                for attr in self.model.all_attributes
+                if hasattr(self, f'{attr}_display')
             },
         )
         return data
